@@ -131,6 +131,25 @@ input: |+
 				true,
 			)
 		})
+
+		It("should report each file level change separately for better readability", func() {
+			compareAgainstExpectedHuman(
+				assets("kubernetes/multi-docs-file-level/from.yaml"),
+				assets("kubernetes/multi-docs-file-level/to.yaml"),
+				assets("kubernetes/multi-docs-file-level/expected-dyff.human"),
+				false,
+			)
+		})
+
+		It("should detect renames for kubernetes documents", func() {
+			compareAgainstExpectedHuman(
+				assets("kubernetes/rename/from.yaml"),
+				assets("kubernetes/rename/to.yaml"),
+				assets("kubernetes/rename/expected-dyff.human"),
+				false,
+				dyff.DetectRenames(true),
+			)
+		})
 	})
 
 	Context("nicely colored human readable differences", func() {
